#include "DEdge.h"

using namespace vii;

/**
 * @brief Construct a new Edge::Edge object.
 *
 */
Edge::Edge()
{
    Me.resize(0, 0.);
    vt.resize(0, 0.);
    rhoe.resize(0, 0.);
    deltaStar.resize(0, 0.);
    vtOld.resize(0, 0.);
}

/**
 * @brief Return the maximum inviscid Mach number in the region.
 *
 * @return double
 */
double Edge::getMaxMach() const
{
    if (Me.size() <= 0)
        throw std::runtime_error("vii::Edge Invalid Mach number vector.");
    double Mmax = 0.0;
    for (size_t i = 0; i < Me.size(); ++i)
        if (Me[i] > Mmax)
            Mmax = Me[i];
    return Mmax;
}

// Setters.
void Edge::setMe(std::vector<double> const _Me)
{
    Me.resize(_Me.size(), 0.);
    Me = _Me;
}
void Edge::setVt(std::vector<double> const _vt)
{
    vt.resize(_vt.size(), 0.);
    vt = _vt;
}
void Edge::setRhoe(std::vector<double> const _rhoe)
{
    rhoe.resize(_rhoe.size(), 0.);
    rhoe = _rhoe;
}
void Edge::setDeltaStar(std::vector<double> const _deltaStar)
{
    deltaStar.resize(_deltaStar.size(), 0.);
    deltaStar = _deltaStar;
}
void Edge::setVtOld(std::vector<double> const _vtOld)
{
    vtOld.resize(_vtOld.size(), 0.);
    vtOld = _vtOld;
}
