#ifndef DEDGE_H
#define DEDGE_H

#include "vii.h"
#include <vector>
#include <iostream>

namespace vii
{

/**
 * @brief Inviscid quantities at the edge of the boundary layer of a BoundaryLayer region.
 * @author Paul Dechamps
 */
class VII_API Edge
{
private:
    std::vector<double> Me;        ///< Mach number.
    std::vector<double> vt;        ///< Velocity.
    std::vector<double> rhoe;      ///< Density.
    std::vector<double> deltaStar; ///< Displacement thickness.
    std::vector<double> vtOld;     ///< Previous velocity.

public:
    Edge();
    ~Edge(){};

    // Getters.
    double getMe(size_t iPoint) const { return Me[iPoint]; };
    double getVt(size_t iPoint) const { return vt[iPoint]; };
    double getRhoe(size_t iPoint) const { return rhoe[iPoint]; };
    double getDeltaStar(size_t iPoint) const { return deltaStar[iPoint]; };
    double getVtOld(size_t iPoint) const { return vtOld[iPoint]; };
    double getMaxMach() const;

    // Setters.
    void setMe(std::vector<double> const _Me);
    void setVt(std::vector<double> const _vt);
    void setRhoe(std::vector<double> const _rhoe);
    void setDeltaStar(std::vector<double> const _deltaStar);
    void setVtOld(std::vector<double> const _vtOld);
};
} // namespace vii
#endif // DEDGE_H
