#ifndef DFLUXES_H
#define DFLUXES_H

#include "vii.h"
#include "DBoundaryLayer.h"
#include <Eigen/Dense>

namespace vii
{

/**
 * @brief Residual and Jacobian computation of the unsteady integral boundary layer equations.
 * @author Paul Dechamps
 */
class VII_API Fluxes
{
public:
    double Re; ///< Freestream Reynolds number.

public:
    Fluxes(double _Re) : Re(_Re){};
    ~Fluxes(){};
    Eigen::VectorXd computeResiduals(size_t iPoint, BoundaryLayer *bl);
    Eigen::MatrixXd computeJacobian(size_t iPoint, BoundaryLayer *bl, Eigen::VectorXd const &sysRes, double eps);

private:
    Eigen::VectorXd blLaws(size_t iPoint, BoundaryLayer *bl, std::vector<double> u);
    double amplificationRoutine(double Hk, double Ret, double theta) const;
};
} // namespace vii
#endif // DFLUXES_H
